Module chmod

Module chmod 

Structs

ChmodConfig
Configuration for chmod operations.

Functions

chmod_file
Apply a mode to a file and return whether a change was made.
chmod_recursive
Recursively apply a mode string to a directory tree.
format_symbolic_for_warning
Format the symbolic mode string for umask-blocked warning messages. Produces output like rwxr-xr-x.
get_umask
Get the current umask value.
parse_mode
Parse a mode string (octal or symbolic) and return the new mode.
parse_mode_check_umask
Parse a mode and also compute whether the umask blocked any requested bits. Returns (new_mode, umask_blocked) where umask_blocked is true if the umask prevented some requested bits from being changed.
parse_mode_no_umask
Like parse_mode but ignores the process umask.