fmt_file

Function fmt_file 

pub fn fmt_file<R: Read, W: Write>(
    input: R,
    output: &mut W,
    config: &FmtConfig,
) -> Result<()>
Reformat text from input and write the result to output.

Text is processed paragraph by paragraph in a streaming fashion. Each paragraph is formatted and written immediately, avoiding holding the entire file in memory.