pub fn hash_bytes(algo: HashAlgorithm, data: &[u8]) -> Result<String>Expand description
Compute hash of a byte slice directly (zero-copy fast path). Returns an error if the underlying crypto library rejects the algorithm.
pub fn hash_bytes(algo: HashAlgorithm, data: &[u8]) -> Result<String>Compute hash of a byte slice directly (zero-copy fast path). Returns an error if the underlying crypto library rejects the algorithm.