pub fn hash_file(algo: HashAlgorithm, path: &Path) -> Result<String>Expand description
Hash a file by path. Uses tiered I/O strategy for regular files, streaming read for non-regular files.
pub fn hash_file(algo: HashAlgorithm, path: &Path) -> Result<String>Hash a file by path. Uses tiered I/O strategy for regular files, streaming read for non-regular files.