readahead_files

Function readahead_files 

pub fn readahead_files(paths: &[&Path])
Issue readahead hints for a list of file paths to warm the page cache. This should be called before parallel hashing to reduce I/O stalls.