pub fn paste_serial_stream(
file_data: &[&[u8]],
config: &PasteConfig,
) -> Result<()>Expand description
Streaming paste for serial mode. For each file, join all lines with the delimiter list (cycling).
pub fn paste_serial_stream(
file_data: &[&[u8]],
config: &PasteConfig,
) -> Result<()>Streaming paste for serial mode. For each file, join all lines with the delimiter list (cycling).