format_long_entry

Function format_long_entry 

pub fn format_long_entry(username: &str, config: &PinkyConfig) -> String
Format output in long format for a specific user. Returns the complete output including trailing newlines, matching GNU pinky:

  • Nonexistent user: “Login name: … In real life: ???\n” (no trailing blank line)
  • Existing user: all info lines + trailing blank line (\n)