Module printf

Module printf 

Functions

had_conv_error
Returns true if a conversion warning occurred since last reset.
process_format_string
Process a printf format string with the given arguments, returning raw bytes.
reset_conv_error
Reset conversion error flag. Call before processing a format string.