Module chmod
coreutils_
rs
0.15.0
Module chmod
Module Items
Structs
Functions
In crate coreutils_
rs
coreutils_rs
Module
chmod
Structs

Chmod
Config
Configuration for chmod operations.
Functions

chmod_
file
Apply a mode to a file and return whether a change was made.
chmod_
recursive
Recursively apply a mode string to a directory tree.
format_
symbolic_
for_
warning
Format the symbolic mode string for umask-blocked warning messages. Produces output like
rwxr-xr-x
.
get_
umask
Get the current umask value.
parse_
mode
Parse a mode string (octal or symbolic) and return the new mode.
parse_
mode_
check_
umask
Parse a mode and also compute whether the umask blocked any requested bits. Returns
(new_mode, umask_blocked)
where
umask_blocked
is true if the umask prevented some requested bits from being changed.
parse_
mode_
no_
umask
Like
parse_mode
but ignores the process umask.