Module io
coreutils_
rs
0.0.50
Module io
Module Items
Enums
Functions
In coreutils_
rs::
common
coreutils_rs
::
common
Module
io
Enums

File
Data
Holds file data — either zero-copy mmap or an owned Vec. Dereferences to
&[u8]
for transparent use.
Functions

file_
size
Get file size without reading it (for byte-count-only optimization).
read_
file
Read a file with zero-copy mmap for large files or read() for small files. Opens once with O_NOATIME, uses fstat for metadata to save a syscall.
read_
stdin
Read all bytes from stdin into a Vec. Pre-allocates 16MB to avoid the repeated reallocation overhead of Vec’s default growth strategy (which doubles from 0 -> 8K -> 16K -> …), causing multiple memcpy of already-read data for large piped inputs.