Functions
- had_
conv_ error - Returns true if a conversion warning occurred since last reset.
- process_
format_ string - Process a printf format string with the given arguments, returning raw bytes.
- reset_
conv_ error - Reset conversion error flag. Call before processing a format string.