pub fn tac_bytes(
data: &[u8],
separator: u8,
before: bool,
out: &mut impl Write,
) -> Result<()>Expand description
Reverse the records in data separated by a single byte separator and write to out.
If before is true, the separator is attached before the record instead of after.
Uses vectored I/O (writev) to write directly from mmap’d data — zero intermediate copies.