pub enum CaseClass {
Upper,
Lower,
}Expand description
Parse a tr character set string into a Vec
Supports:
- Literal characters
- Escape sequences: \, \a, \b, \f, \n, \r, \t, \v, \NNN (octal)
- Ranges: a-z, A-Z, 0-9
- Character classes: [:alnum:], [:alpha:], etc.
- Equivalence classes: [=c=]
- Repeat: [cn] or [c] (SET2 only, handled by caller) Identifies a case-conversion character class and its position in the expanded set.
Variants